@@ -174,7 +174,7 @@ class LayeredImage:
         for x,y in coordgen(*self.image.size):
             pixels[str(px[x,y])].append((x,y))
         for color, coords in pixels.items():
-            color = [int(x) for x in color[:-1][1:].split(', ')]
+            color = eval(color)
             yield ImageLayer(self.image, coords, color)
 
     def layersbyedge(self):
